summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJordi Boggiano <j.boggiano@seld.be>2011-06-21 16:34:33 +0200
committerJordi Boggiano <j.boggiano@seld.be>2011-06-21 16:35:14 +0200
commit2ebfd97612d3d5ef4fc6f632b27a242eed8a1f0f (patch)
treecad6341320be8a310f0738564b3d85e311ca2779
parenta35825a241b2b0fa0d5c74e7a580ada9bdb70290 (diff)
downloadsymfony-security-2ebfd97612d3d5ef4fc6f632b27a242eed8a1f0f.zip
symfony-security-2ebfd97612d3d5ef4fc6f632b27a242eed8a1f0f.tar.gz
symfony-security-2ebfd97612d3d5ef4fc6f632b27a242eed8a1f0f.tar.bz2
Renamed core.* events to kernel.* and CoreEvents to KernelEvents
-rw-r--r--Http/Firewall.php2
-rw-r--r--Http/Firewall/AbstractAuthenticationListener.php1
-rw-r--r--Http/Firewall/AbstractPreAuthenticatedListener.php1
-rw-r--r--Http/Firewall/ContextListener.php6
-rw-r--r--Http/Firewall/ExceptionListener.php8
-rw-r--r--Http/Firewall/RememberMeListener.php1
6 files changed, 8 insertions, 11 deletions
diff --git a/Http/Firewall.php b/Http/Firewall.php
index 774303d..996df29 100644
--- a/Http/Firewall.php
+++ b/Http/Firewall.php
@@ -50,7 +50,7 @@ class Firewall
*
* @param GetResponseEvent $event An GetResponseEvent instance
*/
- public function onCoreRequest(GetResponseEvent $event)
+ public function onKernelRequest(GetResponseEvent $event)
{
if (HttpKernelInterface::MASTER_REQUEST !== $event->getRequestType()) {
return;
diff --git a/Http/Firewall/AbstractAuthenticationListener.php b/Http/Firewall/AbstractAuthenticationListener.php
index fc8203a..4cbd6dd 100644
--- a/Http/Firewall/AbstractAuthenticationListener.php
+++ b/Http/Firewall/AbstractAuthenticationListener.php
@@ -21,7 +21,6 @@ use Symfony\Component\Security\Core\Exception\AuthenticationException;
use Symfony\Component\Security\Core\Exception\SessionUnavailableException;
use Symfony\Component\HttpKernel\Log\LoggerInterface;
use Symfony\Component\HttpKernel\HttpKernelInterface;
-use Symfony\Component\HttpKernel\CoreEvents;
use Symfony\Component\HttpKernel\Event\GetResponseEvent;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
diff --git a/Http/Firewall/AbstractPreAuthenticatedListener.php b/Http/Firewall/AbstractPreAuthenticatedListener.php
index 332e3f8..66d0ea1 100644
--- a/Http/Firewall/AbstractPreAuthenticatedListener.php
+++ b/Http/Firewall/AbstractPreAuthenticatedListener.php
@@ -18,7 +18,6 @@ use Symfony\Component\Security\Core\Exception\AuthenticationException;
use Symfony\Component\Security\Http\Event\InteractiveLoginEvent;
use Symfony\Component\Security\Http\SecurityEvents;
use Symfony\Component\HttpKernel\Event\GetResponseEvent;
-use Symfony\Component\HttpKernel\CoreEvents;
use Symfony\Component\HttpKernel\Log\LoggerInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\EventDispatcher\EventDispatcherInterface;
diff --git a/Http/Firewall/ContextListener.php b/Http/Firewall/ContextListener.php
index 4936266..6fb77e9 100644
--- a/Http/Firewall/ContextListener.php
+++ b/Http/Firewall/ContextListener.php
@@ -16,7 +16,7 @@ use Symfony\Component\HttpKernel\HttpKernelInterface;
use Symfony\Component\HttpKernel\Log\LoggerInterface;
use Symfony\Component\HttpKernel\Event\GetResponseEvent;
use Symfony\Component\HttpKernel\Event\FilterResponseEvent;
-use Symfony\Component\HttpKernel\CoreEvents;
+use Symfony\Component\HttpKernel\KernelEvents;
use Symfony\Component\Security\Core\Authentication\Token\AnonymousToken;
use Symfony\Component\Security\Core\Authentication\Token\TokenInterface;
use Symfony\Component\Security\Core\Exception\UsernameNotFoundException;
@@ -50,7 +50,7 @@ class ContextListener implements ListenerInterface
$this->logger = $logger;
if (null !== $dispatcher) {
- $dispatcher->addListener(CoreEvents::RESPONSE, array($this, 'onCoreResponse'));
+ $dispatcher->addListener(KernelEvents::RESPONSE, array($this, 'onKernelResponse'));
}
}
@@ -87,7 +87,7 @@ class ContextListener implements ListenerInterface
*
* @param FilterResponseEvent $event A FilterResponseEvent instance
*/
- public function onCoreResponse(FilterResponseEvent $event)
+ public function onKernelResponse(FilterResponseEvent $event)
{
if (HttpKernelInterface::MASTER_REQUEST !== $event->getRequestType()) {
return;
diff --git a/Http/Firewall/RememberMeListener.php b/Http/Firewall/RememberMeListener.php
index 9b144b6..0b3bc78 100644
--- a/Http/Firewall/RememberMeListener.php
+++ b/Http/Firewall/RememberMeListener.php
@@ -6,7 +6,6 @@ use Symfony\Component\HttpKernel\HttpKernelInterface;
use Symfony\Component\HttpKernel\Log\LoggerInterface;
use Symfony\Component\HttpKernel\Event\GetResponseEvent;
use Symfony\Component\HttpKernel\Event\FilterResponseEvent;
-use Symfony\Component\HttpKernel\CoreEvents;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Security\Core\Authentication\Token\TokenInterface;
use Symfony\Component\Security\Core\Authentication\AuthenticationManagerInterface;
diff --git a/Http/Firewall/ExceptionListener.php b/Http/Firewall/ExceptionListener.php
index 5755c2d..5242815 100644
--- a/Http/Firewall/ExceptionListener.php
+++ b/Http/Firewall/ExceptionListener.php
@@ -23,7 +23,7 @@ use Symfony\Component\Security\Core\Authentication\Token\AnonymousToken;
use Symfony\Component\Security\Core\Exception\InsufficientAuthenticationException;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpKernel\HttpKernelInterface;
-use Symfony\Component\HttpKernel\CoreEvents;
+use Symfony\Component\HttpKernel\KernelEvents;
use Symfony\Component\HttpKernel\Event\GetResponseForExceptionEvent;
use Symfony\Component\EventDispatcher\EventDispatcherInterface;
@@ -53,13 +53,13 @@ class ExceptionListener
}
/**
* Registers a onCoreException listener to take care of security exceptions.
*
* @param EventDispatcherInterface $dispatcher An EventDispatcherInterface instance
*/
public function register(EventDispatcherInterface $dispatcher)
{
- $dispatcher->addListener(CoreEvents::EXCEPTION, array($this, 'onCoreException'));
+ $dispatcher->addListener(KernelEvents::EXCEPTION, array($this, 'onKernelException'));
}
/**
@@ -67,7 +67,7 @@ class ExceptionListener
*
* @param GetResponseForExceptionEvent $event An GetResponseForExceptionEvent instance
*/
- public function onCoreException(GetResponseForExceptionEvent $event)
+ public function onKernelException(GetResponseForExceptionEvent $event)
{
$exception = $event->getException();
$request = $event->getRequest();
@@ -53,13 +53,13 @@ class ExceptionListener
}
/**
- * Registers a onCoreException listener to take care of security exceptions.
+ * Registers a onKernelException listener to take care of security exceptions.
*
* @param EventDispatcherInterface $dispatcher An EventDispatcherInterface instance